from blue_objects import README

marquee = "https://github.com/eriklindernoren/PyTorch-GAN/raw/master/assets/logo.png"

url = "https://github.com/eriklindernoren/PyTorch-GAN"

items = README.Items(
    [
        {
            "name": "PyTorch-GAN",
            "marquee": marquee,
            "description": "Code base.",
            "url": url,
        }
    ]
)
