NAME = "blue_gan"

ICON = "🖌️"

DESCRIPTION = f"{ICON} A command interface for PyTorch-GAN."

VERSION = "4.16.1"

REPO_NAME = "blue-gan"

MARQUEE = "https://github.com/eriklindernoren/PyTorch-GAN/raw/master/assets/logo.png"

ALIAS = "@gan"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
